function varargout = PIDC2(varargin)
% PIDC2 Application M-file for PIDC2.fig
%    FIG = PIDC2 launch PIDC2 GUI.
%    PIDC2('callback_name', ...) invoke the named callback.




if nargin == 0  % LAUNCH GUI

	fig = openfig(mfilename,'reuse');
    set(fig,'Name','PIDC Version 2.00 beta');
    movegui(fig,'onscreen')

	% Generate a structure of handles to pass to callbacks.
	handles = guihandles(fig);
    guidata(fig, handles);

	if nargout > 0
		varargout{1} = fig;
	end

    % Initializing ...
    initializeGlobals;

    [devices energies] = initializeDevAndEnergy;

    set(handles.popupDevice, 'String', devices);
    set(handles.popupEnergy, 'String', energies);
    guidata(fig, handles);
    % End of initializing.

elseif ischar(varargin{1}) % INVOKE NAMED SUBFUNCTION OR CALLBACK

	try
		[varargout{1:nargout}] = feval(varargin{:}); % FEVAL switchyard
    catch
		disp(lasterr);
    end

end

%-------------------------------------------------------------------------------
function varargout = popupDevice_Callback(h, eventdata, handles, varargin)
% Stub for Callback of the uicontrol handles.popupDevice.
    %set(handles.pushCalculate, 'Enable', 'off'); % Set Analyze button grey
    disableAnalyze(h, handles)
    guidata(h, handles);
    myMessage('',-99);
%-------------------------------------------------------------------------------
function varargout = popupEnergy_Callback(h, eventdata, handles, varargin)
% Stub for Callback of the uicontrol handles.popupEnergia.

    %set(handles.pushCalculate, 'Enable', 'off'); % Set Analyze button grey
    disableAnalyze(h, handles)
    %guidata(h, handles);
    myMessage('',-99);

%-------------------------------------------------------------------------------
function varargout = pushbuttonInput_Callback(h, eventdata, handles, varargin)
% Stub for Callback of the uicontrol handles.pushbuttonInput.

    myMessage('OK',-99);

    [fname,pname] = uigetfile('*.txt','Choose an input file');
    if fname ~= 0
        set(handles.editInput,'String',strcat(pname,fname));
        disableAnalyze(h, handles)
        %set(handles.pushCalculate, 'Enable', 'off');
    end
    
%-------------------------------------------------------------------------------
function disableAnalyze(h, handles)
    set(handles.pushCalculate, 'Enable', 'off'); % Set Analyze button grey
    set(handles.editInput, 'Enable', 'on'); % Set this button enabled
    set(handles.popupSource, 'String', '-');
    set(handles.popupMz, 'String', '-');
    set(handles.popupMz, 'Value', 1);
    set(handles.popupSource, 'Value', 1);
    guidata(h, handles);
%-------------------------------------------------------------------------------
function editInput_ButtonDown(h, eventdata, handles, varargin)
    %beep
    %set(handles.pushCalculate, 'Enable', 'off'); % Set Analyze button grey
    %set(handles.editInput, 'Enable', 'on'); % Set this button enabled
    %guidata(h, handles);
    disableAnalyze(h, handles)
%-------------------------------------------------------------------------------
function varargout = editInput_Callback(h, eventdata, handles, varargin)
% Stub for Callback of the uicontrol handles.editInput.

    myMessage('',-99);

%-------------------------------------------------------------------------------
function varargout = editOutput_Callback(h, eventdata, handles, varargin)
% Stub for Callback of the uicontrol handles.editOutput.

%-------------------------------------------------------------------------------
function varargout = pushbuttonOutput_Callback(h, eventdata, handles, varargin)
% Stub for Callback of the uicontrol handles.pushbuttonOutput.

    myMessage('OK',-99);

    [fname,pname] = uiputfile('*.txt','Choose the output file');
    if fname ~= 0
        set(handles.editOutput,'String',strcat(pname,fname));
    end

%-------------------------------------------------------------------------------
function updatePeaks(updateSource)
    global PeakSelection;
    global PeakList;
    
    ok = 1;
    pl = PeakList(PeakSelection);
    if pl.errorCode == -1
        myMessage(': Fragment database not exist, or no database lines for given input',-99);
        ok = 0;
    elseif pl.errorCode == -2
        myMessage(': Too many labels in mother',-99);
        ok = 0;
    else
        if pl.errorCode == -3
            str = num2str( pl.unknownMz(1) );
            for i = 2 : length(pl.unknownMz)
                str = [str, ',', num2str( pl.unknownMz(i) )];
            end
            myMessage(['Some peaks were not recognized, mz: ', str],-99);
        else
            myMessage('',-99);
        end
    end

    masses = [];
    source = [];
    for i = 1 : length(pl.list)
        masses = strvcat(masses, num2str(pl.list(i).mz));
    end
    if isempty(masses)
        ok = 0;
        masses = '-';
        source = '-';
    else
        source = pl.list(1).str;
        if pl.name == pl.list(1).str
            for i = 1 : length(PeakList)
                if i ~= PeakSelection
                    source = strvcat(source, PeakList(i).list(1).str);
                end
            end
        end
    end

    [h,fig] = gcbo;
    handles = guihandles(fig);
    
    set(handles.popupMz, 'String', masses);
    if updateSource
        set(handles.popupSource, 'String', source);
    end
    if ok
        set(handles.pushCalculate, 'Enable', 'on');
        set(handles.editInput, 'Enable', 'inactive'); % To make editInput_ButtonDown work...
    else
        %set(handles.pushCalculate, 'Enable', 'off');
        disableAnalyze(h, handles)
    end
    guidata(gcbo,handles);
%-------------------------------------------------------------------------------
function varargout = pushbuttonRecognize_Callback(h, eventdata, handles, varargin)
% Stub for Callback of the uicontrol handles.pushbuttonRecognize.

    global FdbArray    % FdbArray contains the entire database
    global InputArray;  % checkInput, if succeeded, creates this global matrix
    global Elements;
    initializeGlobals; %MIKSI TSS KUTSUTAAN UUDESTAAN? YKSI KERTA PITISI RIITT

    myMessage('OK',-99); 
    fname = get(handles.editInput,'String');

    input = readFile(fname);

    if isequal(input,-1)
        myMessage([fname,': Input file does not exist'],-99);
        break;
    end

    [sc, lnum] = parseInput(input);

    if sc < 0
        if sc > -15
            filepos = strcat(fname, ' (', num2str(lnum), '): ');
        else
            filepos = strcat(fname, ': ');
        end
        myMessage(filepos, sc);
        break;
    end

    % Parse the fragment database

    fname = ['fdb_',popupstr(handles.popupDevice),'_', ...
       popupstr(handles.popupEnergy),'.db'];

    input = readFile(fname);

    if isequal(input, -1)
        myMessage([fname,': Fragment database not exist'],-99);
        break;
    end

    [sc, lnum] = parseFDB(input);

    if sc < 0
        if sc > -29
            filepos = strcat(fname, ' (', num2str(lnum), '): ');
        else
            filepos = strcat(fname, ': ');
        end
        myMessage(filepos, sc);
        break;
    end

    global PeakSelection;
    PeakSelection = 1;
    global PeakList;
    PeakList = recognizePeaks;
    updatePeaks(1);
    set(handles.popupMz, 'Value', 1);
    guidata(gcbo,handles);
%-------------------------------------------------------------------------------
%function varargout = pushbuttonCalculate_Callback(h, eventdata, handles, varargin)
function varargout = pushCalculate_Callback(h, eventdata, handles, varargin)
% Stub for Callback of the uicontrol handles.pushbuttonCalculate.
   	global A;
	global B;
	global PeakSelection;
    global MotherMz; 
    global InputArray;
    global N;
    
    N = 1E7;
    myMessage('OK',-99);
    foo = zeros(0,1);
	A = [];
	B = [];
    for i = 1 : length(InputArray)
	    foo(end+1) = InputArray(i).intensity;
    end
	[fragments, fragmentsIso] = findFragments(MotherMz); % mothermz as a parameter

   
    changeIntIntoRelativeInt;
    
	if PeakSelection == 1
        createMotherMatrices(fragments);
	else
        createMotherMatrices(fragmentsIso);
	end
    
    
	%for i = 1 : 50
    %    InputArray = degenerateWithNoise(B,InputArray,N,foo);     
	[A B] = calculate(A, B);
        %A
        %B
    %    foo(:,end+1) = B;
    %end
        
    fn = get(handles.editOutput,'String');
    writeError = writeFile(fn, A, B, popupstr(handles.popupEnergy), popupstr(handles.popupDevice));
    if writeError < 1
      myMessage(strcat('Error writing output to file:', fn), -99);
    end
%-------------------------------------------------------------------------------        
function varargout = popupSource_Callback(h, eventdata, handles, varargin)
    global PeakList;
    global PeakSelection;
    strSelection = popupstr(handles.popupSource);
    for i = 1 : length(PeakList)
       if isequal(PeakList(i).name, strSelection)
           PeakSelection = i;
           updatePeaks(0);
           break;
       end
    end

%-------------------------------------------------------------------------------        
function varargout = popupMz_Callback(h, eventdata, handles, varargin)
    global PeakList;
    global PeakSelection;
    strSelection = popupstr(handles.popupMz);
    selection = str2num(strSelection);

    pl = PeakList(PeakSelection); % currently selected Peaks
    source = [];
    for i = 1 : length(pl.list)
        if pl.list(i).mz == selection
            source = pl.list(i).str;
            break;
        end
    end
    
    if isequal(source, pl.name)
        for i = 1 : length(PeakList)
            if i ~= PeakSelection
               source = strvcat(source, PeakList(i).list(1).str);
            end
        end
    end

    if isempty(source)
        source = '-';
    end
   
    %source
    set(handles.popupSource, 'String', source);
    set(handles.popupSource, 'Value', 1);
    guidata(h, handles);
%-------------------------------------------------------------------------------        
function varargout = pushbuttonFdb_Callback(h, eventdata, handles, varargin)
% Stub for Callback of the uicontrol handles.pushbuttonFragmentti.
     
    fdb = ['fdb_',popupstr(handles.popupDevice),'_', ...
       popupstr(handles.popupEnergy),'.db'];   
    
    if ~exist(fdb)
        myMessage([fdb,': Fragment database does not exist.'],-99);
    else
        edit(fdb);
    end
        
    
    disableAnalyze(h, handles)
    %set(handles.pushCalculate, 'Enable', 'off');
%-------------------------------------------------------------------------------        
function varargout = pushbuttonInputEdit_Callback(h, eventdata, handles, varargin)
% Stub for Callback of the uicontrol handles.pushbuttonInputEdit.
    

    fname = get(handles.editInput,'String');
    
    if ~exist(fname)
        myMessage([fname,': Input file does not exist.'],-99);
    else
        edit(fname);
    end

    %set(handles.pushCalculate, 'Enable', 'off');
    disableAnalyze(h, handles)
%------------------------------------------------------------------------------- 
function varargout = pushbuttonOutputEdit_Callback(h, eventdata, handles, varargin)
% Stub for Callback of the uicontrol handles.pushbuttonOutputEdit.

    fname = get(handles.editOutput,'String');
    
    if ~exist(fname)
        myMessage([fname,' : Output file does not exist.'],-99);
    else
        edit(fname);
    end
%-------------------------------------------------------------------------------        
function varargout = pushbuttonClose_Callback(h, eventdata, handles, varargin)
% Stub for Callback of the uicontrol handles.pushbuttonClose.
    global IonizationMode;
    global AminoAcids;

    IonizationMode = [];
    AminoAcids = [];
    close(handles.figure1);
%-------------------------------------------------------------------------------        
function mutual_exclude(off)
set(off,'Value',0)


% --------------------------------------------------------------------
function varargout = radiobutton1_Callback(h, eventdata, handles, varargin)
    global IonizationMode;

    IonizationMode = -1;
    off = [handles.radiobutton2];
    mutual_exclude(off);
    %setAminoAcidWeights(-1); %kludge to handle both positive and negative ionization modes

% --------------------------------------------------------------------
function varargout = radiobutton2_Callback(h, eventdata, handles, varargin)
    global IonizationMode;

    IonizationMode = 1;
    off = [handles.radiobutton1];
    mutual_exclude(off);
    %setAminoAcidWeights(1);%kludge to handle both positive and negative ionization modes


% --------------------------------------------------------------------
function varargout = pushbutton16_Callback(h, eventdata, handles, varargin)
    addCurrentToConstraints;
    
% --------------------------------------------------------------------
function varargout = pushbutton17_Callback(h, eventdata, handles, varargin)

    global constrMat;
    global constrVect;
    
    global constrComments;
    global constrDatalines;

    [constrMat constrVect] = calculate(constrMat,constrVect);
        %A
        %B
    %    foo(:,end+1) = B;
    %end
        
    fn = get(handles.editOutput,'String');
    writeError = writeFile(fn, constrMat, constrVect, 'combined ', 'combined ');
    if writeError < 1
      myMessage(strcat('Error writing output to file:', fn), -99);
    end
    
    constrMat = [];
    constrVect = [];

    constrComments = [];
    constrDatalines = [];

% --------------------------------------------------------------------


