function initializeGlobals
% Initializes global variables.

% Mika Miettinen

    global EPSILON;
    global Elements;
    global AminoAcids;
    global InputArray; % struct-array used for storing the input
    global InputComments; % array for comments at the beginning of input
    global InputDatalines; % array containing datalines of the input
    global IonizationMode; 
    global IsInitialized;
    
    
    EPSILON = 1e-8;
    InputArray = struct('mz', {}, 'intensity', {}, 'mother', {});
    InputComments = struct('line', {});
    InputDatalines = struct('line', {});
    AminoAcids = struct('name', {}, 'mass', {}, 'fragments', {});

    % Table of natural abundances and masses of elements

    Elements(1).name = 'C';
    Elements(1).weight = 12;
    Elements(1).isotopes = [0.98912, 0.01088];
    
    Elements(2).name ='H';
    Elements(2).weight = 1;
    Elements(2).isotopes = [0.99985, 0.00015];

    Elements(3).name = 'N';
    Elements(3).weight = 14;
    Elements(3).isotopes = [0.99631, 0.00368];

    Elements(4).name = 'O';
    Elements(4).weight = 16;
    Elements(4).isotopes = [0.99761, 0.00039, 0.00200];

    Elements(5).name = 'S';
    Elements(5).weight = 32;
    Elements(5).isotopes = [0.95057, 0.00760, 0.04183];

    Elements(6).name = 'SI';
    Elements(6).weight = 28;
    Elements(6).isotopes = [0.92166, 0.04701, 0.03134];

    Elements(7).name = 'P'; 
    Elements(7).weight = 31;
    Elements(7).isotopes = [1.0];

    % Names of the 20 amino acids and 16 sugar phosphates and their molecular masses
   
    AminoAcids(1).name = 'GLY';
    AminoAcids(1).mass = 75;
    AminoAcids(2).name = 'ALA';
    AminoAcids(2).mass = 89;
    AminoAcids(3).name = 'VAL';
    AminoAcids(3).mass = 117;
    AminoAcids(4).name = 'LEU';
    AminoAcids(4).mass = 131;
    AminoAcids(5).name = 'ILE';
    AminoAcids(5).mass = 131;
    AminoAcids(6).name = 'MET';
    AminoAcids(6).mass = 149;
    AminoAcids(7).name = 'SER';
    AminoAcids(7).mass = 105;
    AminoAcids(8).name = 'CYS';
    AminoAcids(8).mass = 121;
    AminoAcids(9).name = 'PRO';
    AminoAcids(9).mass = 115;
    AminoAcids(10).name = 'THR';
    AminoAcids(10).mass = 119;
    AminoAcids(11).name = 'ASN';
    AminoAcids(11).mass = 132;
    AminoAcids(12).name = 'GLN';
    AminoAcids(12).mass = 146;
    AminoAcids(13).name = 'ASP';
    AminoAcids(13).mass = 133;
    AminoAcids(14).name = 'GLU';
    AminoAcids(14).mass = 147;
    AminoAcids(15).name = 'LYS';
    AminoAcids(15).mass = 146;
    AminoAcids(16).name = 'ARG';
    AminoAcids(16).mass = 174;
    AminoAcids(17).name = 'HIS';
    AminoAcids(17).mass = 155;
    AminoAcids(18).name = 'TYR';
    AminoAcids(18).mass = 181;
    AminoAcids(19).name = 'PHE';
    AminoAcids(19).mass = 165;
    AminoAcids(20).name = 'TRP';
    AminoAcids(20).mass = 204;
    AminoAcids(21).name = 'G6P';
    AminoAcids(21).mass = 260;
    AminoAcids(22).name = 'F6P';
    AminoAcids(22).mass = 260;
    AminoAcids(23).name = 'R5P';
    AminoAcids(23).mass = 230;
    AminoAcids(24).name = 'Ri5P';
    AminoAcids(24).mass = 230;
    AminoAcids(25).name = 'PEP';
    AminoAcids(25).mass = 168;
    AminoAcids(26).name = 'DHAP';
    AminoAcids(26).mass = 170;
    AminoAcids(27).name = 'F16BP';
    AminoAcids(27).mass = 340;
    AminoAcids(28).name = 'Er4P';
    AminoAcids(28).mass = 200;
    AminoAcids(29).name = '3PG';
    AminoAcids(29).mass = 186;
    AminoAcids(30).name = 'GAP';
    AminoAcids(30).mass = 244;
    AminoAcids(31).name = 'NAD';
    AminoAcids(31).mass = 663;
    AminoAcids(33).name = 'NADP';
    AminoAcids(33).mass = 743;
    AminoAcids(34).name = 'AMP';
    AminoAcids(34).mass = 347;
    AminoAcids(35).name = 'ADP';
    AminoAcids(35).mass = 427;
    AminoAcids(36).name = 'ATP';
    AminoAcids(36).mass = 507;
    AminoAcids(37).name = 'PyA';
    AminoAcids(37).mass = 88;

    if isempty(IonizationMode)
        IonizationMode = 1;
    end
    if IonizationMode == -1 %kludge to handle negative ionization mode
        for i = 1 : length(AminoAcids)
            AminoAcids(i).mass = AminoAcids(i).mass - 2;    
        end
    end
    
    for i = 1 : length(AminoAcids)
        AminoAcids(i).mass = AminoAcids(i).mass + 1;
        AminoAcids(i).fragments = struct('molecule', {}, ...
                                         'role', {}, ...
                                         'formula', {}, ...
                                         'carbons', {}, ...
                                         'mz', {}, ...
                                         'probability', {});
    end


