function initializeGlobals
% Initializes global variables.

% Mika Miettinen

    global EPSILON;
    global Elements;
    global AminoAcids;
    global InputArray; % struct-array used for storing the input
    global InputComments; % array for comments at the beginning of input
    global InputDatalines; % array containing datalines of the input
    global IonizationMode; 
    global IsInitialized;
    
    
    
    EPSILON = 1e-8;
    InputArray = struct('mz', {}, 'intensity', {}, 'mother', {});
    InputComments = struct('line', {});
    InputDatalines = struct('line', {});
    AminoAcids = struct('name', {}, 'mass', {}, 'fragments', {});
   
    
    % Table of natural abundances and masses of elements
    Elements(1).name ='H';
    Elements(1).weight = 1;
    Elements(1).isotopes = [0.99985, 0.00015];

    Elements(2).name = 'C';
    Elements(2).weight = 12;
    Elements(2).isotopes = [0.98912, 0.01088];

    Elements(3).name = 'N';
    Elements(3).weight = 14;
    Elements(3).isotopes = [0.99631, 0.00368];

    Elements(4).name = 'O';
    Elements(4).weight = 16;
    Elements(4).isotopes = [0.99761, 0.00039, 0.00200];

    Elements(5).name = 'S';
    Elements(5).weight = 32;
    Elements(5).isotopes = [0.95057, 0.00760, 0.04183];

    Elements(6).name = 'SI';
    Elements(6).weight = 28;
    Elements(6).isotopes = [0.92166, 0.04701, 0.03134];

    % Names of the 20 amino acids and their [M+H]-ion masses
    AminoAcids(1).name = 'GLY';
    AminoAcids(1).mass = 76;
    AminoAcids(2).name = 'ALA';
    AminoAcids(2).mass = 90;
    AminoAcids(3).name = 'VAL';
    AminoAcids(3).mass = 118;
    AminoAcids(4).name = 'LEU';
    AminoAcids(4).mass = 132;
    AminoAcids(5).name = 'ILE';
    AminoAcids(5).mass = 132;
    AminoAcids(6).name = 'MET';
    AminoAcids(6).mass = 150;
    AminoAcids(7).name = 'SER';
    AminoAcids(7).mass = 106;
    AminoAcids(8).name = 'CYS';
    AminoAcids(8).mass = 122;
    AminoAcids(9).name = 'PRO';
    AminoAcids(9).mass = 116;
    AminoAcids(10).name = 'THR';
    AminoAcids(10).mass = 120;
    AminoAcids(11).name = 'ASN';
    AminoAcids(11).mass = 133;
    AminoAcids(12).name = 'GLN';
    AminoAcids(12).mass = 147;
    AminoAcids(13).name = 'ASP';
    AminoAcids(13).mass = 134;
    AminoAcids(14).name = 'GLU';
    AminoAcids(14).mass = 148;
    AminoAcids(15).name = 'LYS';
    AminoAcids(15).mass = 147;
    AminoAcids(16).name = 'ARG';
    AminoAcids(16).mass = 175;
    AminoAcids(17).name = 'HIS';
    AminoAcids(17).mass = 156;
    AminoAcids(18).name = 'TYR';
    AminoAcids(18).mass = 182;
    AminoAcids(19).name = 'PHE';
    AminoAcids(19).mass = 166;
    AminoAcids(20).name = 'TRP';
    AminoAcids(20).mass = 205;

    if isempty(IonizationMode)
        IonizationMode = 1;
    end
    if IonizationMode == -1 %kludge to handle negative ionization mode
        for i = 1 : length(AminoAcids)
            AminoAcids(i).mass = AminoAcids(i).mass - 2;    
        end
    end
    
    for i = 1 : length(AminoAcids)
        AminoAcids(i).fragments = struct('molecule', {}, ...
                                         'role', {}, ...
                                         'formula', {}, ...
                                         'carbons', {}, ...
                                         'mz', {}, ...
                                         'probability', {});
    end

