function y = parseCarbons(carbonStr)
% parseCarbons: parses a carbon sequence represented as a string
% Parameters:
%  carbonStr = carbon sequence as a string

% Mika Miettinen

    maxLength = 50;
    carbons = zeros(1, maxLength);
    state = 0;
    num = 0;
    for i = 1 : length(carbonStr)
        curr = upper(carbonStr(i));
        switch state
        case 0
            if curr == 'C'
                state = 1;
            else
                state = 9;
            end
        case 1
            if isDigit(curr) & curr >= '1'
                state = 2;
                num = curr - '0';
            else
                state = 9;
            end
        case 2
            if isDigit(curr)
                state = 3;
                num = num*10 + (curr - '0');
            elseif curr == 'C'
                % check previous carbon position
                if carbons(num) == 1
                    % This carbon has already been set; error
                    state = 9;
                else
                    % legal carbon position; set it
                    carbons(num) = 1;
                    num = 0;
                    state = 1;
                end
            else
                state = 9;
            end
        case 3
            if curr == 'C'
                % check previous carbon position
                if num > maxLength
                    % illegal carbon position
                    state = 9;
                elseif carbons(num) == 1
                    % this carbon has already been set; error
                    state = 9;
                else
                    % legal carbon position; set it
                    carbons(num) = 1;
                    num = 0;
                    state = 1;
                end
            else
                state = 9;
            end
        case 9
            break;
        end
    end

    if (state == 2 | state == 3) & (num > 0 & num <= maxLength)
        % check carbon position
        if carbons(num) == 1
            % This carbon has already been set; error
            carbons = [];
        else
            % legal carbon position; set it
            carbons(num) = 1;
            num = 0;
            state = 1;
        end
    else
        carbons = [];
    end

    if isempty(carbons)
        y = 0;
    else
        y = 1;
    end

