%Pasi Rastas
function ret = recognizePeaks
% Resolves peaks ~
% input : -
% output: array of struct(list, errorCode, unknownMz, name)
% errorCode     1 : ok
%              -1 : Database empty (for selected mother from inputfile)
%              -2 : Too many labels in mother
%              -3 : Not all peaks were resolved
%list:
%array of struct struct(mz, str, formula)
%str : string presentation of formula (for mother three letters eg. ALA)
%mz : m/z value
%formula : formula of molecule
%name : three letters for mother, eg. ALA
%

	global MotherMz;
	MotherMz = Inf;
	
	global InputArray;
	global AminoAcids;
	
	
	for i = 1 : length(InputArray)
        if isnan(InputArray(i).mother) %  mother
            MotherMz = min(MotherMz, InputArray(i).mz);
        end
	end
	
	motherName = struct('name', {''});
	j = 1;
	for i = 1 : length(AminoAcids)
        if AminoAcids(i).mass == MotherMz
           motherName(j).name = AminoAcids(i).name;
           j = j + 1;
        end
	end
	
	[fdb fdbIso] = findFragments(MotherMz);
	
	ret = struct('list', {}, 'errorCode', {}, 'unknownMz', {}, 'name', {});
	[ret(1).list ret(1).errorCode ret(1).unknownMz] = resPeaks(fdb, motherName(1).name);
	ret(1).name = motherName(1).name;
	if length(motherName) > 1
        [ret(2).list ret(2).errorCode ret(2).unknownMz] = resPeaks(fdbIso, motherName(2).name);
        ret(2).name = motherName(2).name;
        %if ret(1).errorCode < 1 & ret(2).errorCode == 1JK
        %    tmp = ret(1);
        %    ret(1) = ret(2);
        %    ret(2) = tmp;
        %end
	end


function [list, errorCode, unknownMz] = resPeaks(fdb, motherName)
	global MotherMz;
	global InputArray;
	global AminoAcids;
	
	maxMother = -inf;
	peak = [];
	k = 1;
	resolved = [];
	for i = 1 : length(InputArray)
        if isnan(InputArray(i).mother) %  mother
            maxMother = max(maxMother, InputArray(i).mz);
            peak(k).mz = InputArray(k).mz;
            k = k + 1;
            resolved(i) = 1;
        else
            resolved(i) = 0;
        end
	end
	
	if isempty(fdb)
        list = [];
    	unknownMz = [];
        errorCode = -1; % Database empty
        break;
	end
	
	if maxMother - MotherMz > maxNumberOfLabels(fdb(1).formula) % formula
        errorCode = -2; % Too many labels in mother
        list = [];
    	unknownMz = [];
        break;
	end
	
	for i = 1 : length(peak)
        peak(i).formula = fdb(1).formula;
	end
	
	for i = 1 : length(InputArray)
        if ~isnan(InputArray(i).mother) %daughter
            for j = 1 : length(fdb)
                maxLables = maxMother - MotherMz;%maxNumberOfLabels(fdb(j).formula);
                if fdb(j).mz <= InputArray(i).mz & fdb(j).mz + maxLables >= InputArray(i).mz  % and probability > 0
                  resolved(i) = 1;
                  peak(k).mz = InputArray(i).mz;
                  peak(k).formula = fdb(j).formula;
                  peak(k).mother = InputArray(i).mother;
                  k = k + 1;
                end
            end
        end
	end
	
	list = struct('mz', {}, 'str', {}, 'formula', {});
	k = 1;
	for i = 1 : length(peak)
        found = 0;
        for j = 1 : length(list)
            if list(j).mz == peak(i).mz
                if isequal(list(j).formula, peak(i).formula)
                else
                    list(j).str = strcat(list(j).str, '/', formula2str(peak(i).formula));
                end
                found = 1;
            end
        end
        if found == 0
            if (peak(i).mz < MotherMz)
                list(k).str = formula2str(peak(i).formula);
            else
                list(k).str = motherName;
            end
            list(k).mz = peak(i).mz;
            list(k).formula = peak(i).formula;
            k = k + 1;
        end
	end
	
	unknownMz = [];
	j = 1;
	for i = 1 : length(InputArray)
        if resolved(i) == 0
            unknownMz(j) = InputArray(i).mz;
            j = j + 1;
        end
	end
	if isempty(unknownMz)
        errorCode = 1; % ok
	else
        errorCode = -3; % Not all peaks were resolved
	end

function s = formula2str(formula)
	
    %MIK TM ON????
    %TM KOKONAAN UUSIKSI
    %rest = 'C H N O S Si';
	%token = '';
	s = '';
	
	%for i = 1 : 6
    %    [token, rest] = strtok(rest);
    %    if formula(i).atomCnt > 1
    %        s = strcat(s, token, num2str(formula(i).atomCnt));
    %    elseif formula(i).atomCnt == 1
    %        s = strcat(s, token);
    %    end
    %end
    for i = 1 : length(formula)
        
        if formula(i).atomCnt > 0
            s = strcat(s,formula(i).name);
            if formula(i).atomCnt > 1
                s = strcat(s,num2str(formula(i).atomCnt));
            end
        end   
    end
