% Pasi Rastas
function error = writeFile(filename, A, B, energy, instrument)
% Writes outputfile, size(A, 2) must be 2^k, for some integer k and size(A, 1) = size(B).
% input : 
% filename : filename to write output
% A: matrix to write
% B: vector to write 
% energy: energy of fragment database 
% instrument: instrument used to make input
% output: (to file) A x = B.
% error: 1, ok
%       -1, could not open file

    error = 1;
    global EPSILON;
	global InputComments;
	global InputDatalines;
    global constrComments;
    global constrDatalines;

    % Change all near zero value to 0
    fret = find(abs(A) < EPSILON);
    for (i = 1 : length(fret))
        A(fret(i)) = 0;
    end
    % Change all near 1 value to 1
    fret = find(abs(A - 1) < EPSILON);
    for (i = 1 : length(fret))
        A(fret(i)) = 1;
    end
    % Change all near -1 value to -1
    fret = find(abs(A + 1) < EPSILON);
    for (i = 1 : length(fret))
        A(fret(i)) = -1;
    end
    
	
	output = [];
	bits = log2(size(A, 2) - 1);
	desimals = round(-log10(EPSILON));
	if desimals <= 0
        desimals = 1;
	end
	
	fid = fopen(filename, 'w+');
	if isequal(fid, -1) % Cannot open file
        error = -1;
        break;
	end
	fprintf(fid, strcat('%%Date:', date, '\n'));
	fprintf(fid, strcat('%%Energy:', energy, 'eV\n')); % Hard coded eV
	fprintf(fid, strcat('%%Instrument:', instrument, '\n\n'));
	
	fprintf(fid, '%%InputFile:\n');
	
    if strcmp(energy,'combined ') %kludge to determine if combined constraints are to be outputted
        for i = 1 : length(constrComments)
            str = strrep(constrComments(i).line, '%', '');
            fprintf(fid, strcat('%%', str, '\n'));
	    end
	    for i = 1 : length(constrDatalines)
            str = strrep(constrDatalines(i).line, '%', '');
            fprintf(fid, strcat('%%' , str, '\n'));
	    end
    else
        
	    for i = 1 : length(InputComments)
            str = strrep(InputComments(i).line, '%', '');
            fprintf(fid, strcat('%%', str, '\n'));
	    end
	    for i = 1 : length(InputDatalines)
            str = strrep(InputDatalines(i).line, '%', '');
            fprintf(fid, strcat('%%' , str, '\n'));
	    end
    end
	fprintf(fid, '\n');
	
	
	for i = 1 : size(A, 1)
        plus = 0;
        str = '';
        for j = 1 : size(A, 2)
            if A(i, j) ~= 0
                str2 = '+';
                if ~plus
                    str2  = '';
                    plus = 1;
                end
                if A(i, j) < 0
                    str2 = '-';
                end
	
                if abs( A(i, j) ) ~= 1
                    str2 = strcat(str2, num2str(abs(A(i, j)), desimals), '');
                end
                str = strcat(str, str2, '[', dec2bin(j - 1, bits), ']');
            end
        end
        str = strcat(str, '\t', num2str( B(i), desimals ), '\n');
        output = strvcat(output, str);
        fprintf(fid, str);
	end
	fclose(fid);



